=== removed file 'cmake/Toolchain-Ubuntu-GCC44.cmake'
--- cmake/Toolchain-Ubuntu-GCC44.cmake	2012-10-11 07:41:17 +0000
+++ cmake/Toolchain-Ubuntu-GCC44.cmake	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-# Sample toolchain file for building for ARM from an Ubuntu Linux system.
-#
-# Typical usage:
-#    *) install gcc 4.4: sudo apt-get install gcc-4.4 g++-4.4
-#    *) cd build
-#    *) cmake -DCMAKE_TOOLCHAIN_FILE=../Toolchain-Ubuntu-GCC44.cmake ..
-
-set(CMAKE_SYSTEM_NAME Linux)
-set(TOOLCHAIN_PREFIX )
-set(TOOLCHAIN_SUFFIX -4.4)
-
-# Native but non-default compilers 
-set(CMAKE_C_COMPILER ${TOOLCHAIN_PREFIX}gcc${TOOLCHAIN_SUFFIX})
-set(CMAKE_CXX_COMPILER ${TOOLCHAIN_PREFIX}g++${TOOLCHAIN_SUFFIX})

=== modified file 'cross-compile.sh'
--- cross-compile.sh	2012-11-13 19:21:54 +0000
+++ cross-compile.sh	2012-11-19 19:21:52 +0000
@@ -1,33 +1,40 @@
-# Script to help in cross compiling for Android.
-# Assumes that a standalone ndk is available, that
-# contains all of mir's dependencies in its subfolder
-# sysroot.
-# Please adjust ANDROID_STANDALONE_TOOLCHAIN to your own setup.
-
-cwd=`pwd`
-mkdir $1
-cd $1
+#!/bin/sh
+# build script for Mir on android arm devices
+# set $MIR_ANDROID_NDK_DIR to the android toolchain noted in DEPENDENCIES
+# test run requires package 'android-tools-adb' 
+#
+set -e
+
+if [ ! -e $MIR_ANDROID_NDK_DIR ]; then
+    echo "aborting: MIR_ANDROID_NDK_DIR not set. set to path containing mir NDK"
+    exit
+fi
+
 export MIR_NDK_PATH=$MIR_ANDROID_NDK_DIR
-
-cmake -DCMAKE_TOOLCHAIN_FILE=../cmake/AndroidCrossCompile.cmake \
--DBoost_COMPILER=-gcc \
--DMIR_ENABLE_DEATH_TESTS=NO \
--DMIR_INPUT_ENABLE_EVEMU=NO \
--DMIR_PLATFORM=android \
-$cwd
-
-make 
-
-$MIR_ANDROID_SDK_DIR/platform-tools/adb push lib/libmirclient.so.0.0.1 /data/user
-
-$MIR_ANDROID_SDK_DIR/platform-tools/adb push bin/acceptance-tests /data/user
-$MIR_ANDROID_SDK_DIR/platform-tools/adb shell 'cd /data/user && LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH GTEST_OUTPUT=xml:./ ./acceptance-tests'
-$MIR_ANDROID_SDK_DIR/platform-tools/adb pull '/data/user/acceptance-tests.xml'
-
-$MIR_ANDROID_SDK_DIR/platform-tools/adb push bin/integration-tests /data/user
-$MIR_ANDROID_SDK_DIR/platform-tools/adb shell 'cd /data/user && LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH GTEST_OUTPUT=xml:./ ./integration-tests'
-$MIR_ANDROID_SDK_DIR/platform-tools/adb pull '/data/user/integration-tests.xml'
-
-$MIR_ANDROID_SDK_DIR/platform-tools/adb push bin/unit-tests /data/user
-$MIR_ANDROID_SDK_DIR/platform-tools/adb shell 'cd /data/user && LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH GTEST_OUTPUT=xml:./ ./unit-tests'
-$MIR_ANDROID_SDK_DIR/platform-tools/adb pull '/data/user/unit-tests.xml'
+BUILD_DIR=build-android-arm
+if [ ! -e ${BUILD_DIR} ]; then
+    mkdir ${BUILD_DIR}
+    ( cd ${BUILD_DIR} &&
+      cmake -DCMAKE_TOOLCHAIN_FILE=../cmake/AndroidCrossCompile.cmake \
+          -DBoost_COMPILER=-gcc \
+          -DMIR_ENABLE_DEATH_TESTS=NO \
+          -DMIR_INPUT_ENABLE_EVEMU=NO \
+          -DMIR_PLATFORM=android \
+          .. )
+fi
+
+cmake --build ${BUILD_DIR}
+
+adb push ${BUILD_DIR}/lib/libmirclient.so.0.0.1 /data
+
+adb push ${BUILD_DIR}/bin/acceptance-tests /data
+adb shell 'cd /data && LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH GTEST_OUTPUT=xml:./ ./acceptance-tests'
+adb pull '/data/acceptance-tests.xml'
+
+adb push ${BUILD_DIR}/bin/integration-tests /data
+adb shell 'cd /data && LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH GTEST_OUTPUT=xml:./ ./integration-tests'
+adb pull '/data/integration-tests.xml'
+
+adb push ${BUILD_DIR}/bin/unit-tests /data
+adb shell 'cd /data && LD_LIBRARY_PATH=.:$LD_LIBRARY_PATH GTEST_OUTPUT=xml:./ ./unit-tests'
+adb pull '/data/unit-tests.xml'

=== modified file 'native-compile.sh'
--- native-compile.sh	2012-11-05 16:30:47 +0000
+++ native-compile.sh	2012-11-19 19:21:52 +0000
@@ -1,14 +1,17 @@
 #!/bin/sh
 # Native build script for Mir
 #
-# Builds the project with gcc-4.4, as specified by the toolchain file
 set -e
 
-CMAKE_TOOLCHAIN_FILE=cmake/Toolchain-Ubuntu-GCC44.cmake
-
-if [ ! -e build-native ]; then
-    mkdir build-native
-    ( cd build-native && cmake -DCMAKE_TOOLCHAIN_FILE=../$CMAKE_TOOLCHAIN_FILE ..)
+BUILD_DIR=build-linux-x86
+if [ ! -e ${BUILD_DIR} ]; then
+    mkdir ${BUILD_DIR}
+    ( cd ${BUILD_DIR} && cmake ..)
 fi
 
-cmake --build build-native
+cmake --build ${BUILD_DIR}
+
+GTEST_OUTPUT=xml:./
+${BUILD_DIR}/bin/acceptance-tests
+${BUILD_DIR}/bin/integration-tests
+${BUILD_DIR}/bin/unit-tests

